# BACKUP ID SHORTCUTS {#shortcuts}

Rather than using the timestamp backup ID, you can use any of the
following shortcuts/aliases to identity a backup for a given server:

first
:   Oldest available backup for that server, in chronological order.

last
:   Latest available backup for that server, in chronological order.

latest
:   same ast *last*.

oldest
:   same ast *first*.

last-failed
:   Latest failed backup, in chronological order.
